# File: bin/test-marker-stats.ps1
# Purpose: Windows wrapper for reporting pytest marker counts during Phase 1 rollout.
# Context: Mirrors bin/test-marker-stats for PowerShell users.

$ErrorActionPreference = 'Stop'

$scriptDir = Split-Path -Parent $MyInvocation.MyCommand.Path
$rootDir = Split-Path -Parent $scriptDir
Set-Location $rootDir

python scripts/report_marker_stats.py @args
